
#ifndef _C13_kl632_
#define _C13_kl632_

#ifdef __cplusplus
extern "C" {
#endif

extern void F753_4124(EIF_REFERENCE, EIF_INTEGER_32);
extern void EIF_Minit632(void);

#ifdef __cplusplus
}
#endif

#endif
